@@ -18,12 +18,9 @@ from pystencils.integer_functions import (
     int_div, int_power_of_2, modulo_ceil)
 
 try:
-    from sympy.printing.ccode import C99CodePrinter as CCodePrinter
+    from sympy.printing.c import C99CodePrinter as CCodePrinter  # for sympy versions > 1.6
 except ImportError:
-    try:
-        from sympy.printing.ccode import CCodePrinter  # for sympy versions < 1.1
-    except ImportError:
-        from sympy.printing.c import C11CodePrinter as CCodePrinter  # for sympy versions > 1.6
+    from sympy.printing.ccode import C99CodePrinter as CCodePrinter
 
 __all__ = ['generate_c', 'CustomCodeNode', 'PrintNode', 'get_headers', 'CustomSympyPrinter']
 
